@@ -27,6 +27,7 @@ import xlrd
 from telegram_payment_bot.config import ConfigTypes
 from telegram_payment_bot.payments_loader_base import PaymentsLoaderBase
 from telegram_payment_bot.payments_data import PaymentErrorTypes, SinglePayment, PaymentsData, PaymentsDataErrors
+from telegram_payment_bot.user import User
 
 
 #
@@ -45,10 +46,10 @@ class PaymentsExcelLoader(PaymentsLoaderBase):
     def LoadAll(self) -> PaymentsData:
         return self.__LoadAndCheckAll()[0]
 
-    # Load single payment by username
-    def LoadSingleByUsername(self,
-                             username: str) -> Optional[SinglePayment]:
-        return self.LoadAll().GetByUsername(username)
+    # Load single payment by user
+    def LoadSingleByUser(self,
+                         user: User) -> Optional[SinglePayment]:
+        return self.LoadAll().GetByUser(user)
 
     # Check for errors
     def CheckForErrors(self) -> PaymentsDataErrors:
@@ -88,7 +89,7 @@ class PaymentsExcelLoader(PaymentsLoaderBase):
 
         # Get column indexes
         email_col_idx = self._ColumnToIndex(self.config.GetValue(ConfigTypes.PAYMENT_EMAIL_COL))
-        username_col_idx = self._ColumnToIndex(self.config.GetValue(ConfigTypes.PAYMENT_USERNAME_COL))
+        user_col_idx = self._ColumnToIndex(self.config.GetValue(ConfigTypes.PAYMENT_USER_COL))
         expiration_col_idx = self._ColumnToIndex(self.config.GetValue(ConfigTypes.PAYMENT_EXPIRATION_COL))
 
         # Read each row
@@ -97,12 +98,12 @@ class PaymentsExcelLoader(PaymentsLoaderBase):
             if i > 0:
                 # Get cell values
                 email = str(sheet.cell_value(i, email_col_idx)).strip()
-                username = str(sheet.cell_value(i, username_col_idx)).strip()
+                user = User.FromString(self.config, str(sheet.cell_value(i, user_col_idx)).strip())
                 expiration = sheet.cell_value(i, expiration_col_idx)
 
-                # Skip empty usernames
-                if username != "":
-                    self.__AddPayment(i + 1, payments_data, payments_data_err, email, username, expiration)
+                # Skip invalid users
+                if user.IsValid():
+                    self.__AddPayment(i + 1, payments_data, payments_data_err, email, user, expiration)
 
         return payments_data, payments_data_err
 
@@ -112,39 +113,41 @@ class PaymentsExcelLoader(PaymentsLoaderBase):
                      payments_data: PaymentsData,
                      payments_data_err: PaymentsDataErrors,
                      email: str,
-                     username: str,
+                     user: User,
                      expiration: Any) -> None:
         # In Excel, a date can be a number or a string
         try:
-            expiration_datetime = xlrd.xldate_as_datetime(expiration, 0)
+            expiration_datetime = xlrd.xldate_as_datetime(expiration, 0).date()
         except TypeError:
             try:
                 expiration_datetime = datetime.strptime(expiration.strip(),
-                                                        self.config.GetValue(ConfigTypes.PAYMENT_DATE_FORMAT))
+                                                        self.config.GetValue(ConfigTypes.PAYMENT_DATE_FORMAT)).date()
             except ValueError:
                 self.logger.GetLogger().warning(
-                    f"Expiration date for username @{username} at row {row_idx} is not valid ({expiration}), skipped"
+                    f"Expiration date for user {user} at row {row_idx} is not valid ({expiration}), skipped"
                 )
                 # Add error
                 payments_data_err.AddPaymentError(PaymentErrorTypes.INVALID_DATE_ERR,
                                                   row_idx,
-                                                  username,
+                                                  email,
+                                                  user,
                                                   expiration)
                 return
 
         # Add data
-        if payments_data.AddPayment(email, username, expiration_datetime):
+        if payments_data.AddPayment(email, user, expiration_datetime):
             self.logger.GetLogger().debug(
-                f"{payments_data.Count():4d} - Row {row_idx:4d} | {email} | {username} | {expiration_datetime.date()}"
+                f"{payments_data.Count():4d} - Row {row_idx:4d} | {email} | {user} | {expiration_datetime}"
             )
         else:
             self.logger.GetLogger().warning(
-                f"Username @{username} is present more than one time at row {row_idx}, skipped"
+                f"Email {email} or user {user} is present more than one time at row {row_idx}, skipped"
             )
             # Add error
-            payments_data_err.AddPaymentError(PaymentErrorTypes.DUPLICATED_USERNAME_ERR,
+            payments_data_err.AddPaymentError(PaymentErrorTypes.DUPLICATED_PAYMENT_ERR,
                                               row_idx,
-                                              username)
+                                              email,
+                                              user)
 
     # Get sheet
     @staticmethod
